<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="120px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="24">
          <el-form-item label="工序" prop="operationName">
            <el-input
              v-model="dataForm.operationName"
              placeholder="工序"
              :disabled="dataForm.id != null && dataForm.id > 0"
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openOperationDialog()"
                v-show="!dataForm.id"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="机台" prop="workstationNo">
            <el-input
              v-model="dataForm.workstationNo"
              placeholder="机台"
              :disabled="dataForm.id != null && dataForm.id > 0"
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openWorkstationDialog()"
                v-show="!dataForm.id"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="零件号" prop="partNo">
            <el-input
              v-model="dataForm.partNo"
              placeholder="零件号"
              :disabled="dataForm.id != null && dataForm.id > 0"
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openPartDialog()"
                v-show="!dataForm.id"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="定额" prop="quota">
            <el-input v-model="dataForm.quota" placeholder="定额"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <part-dialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPart"
    />
    <operation-dialog
      :currshowlist.sync="showOperate"
      @listenToOperationEvent="selectOperation"
    />
    <workstation-dialog
      :currshowlist.sync="showWorkstation"
      @listenToWorkStationEvent="selectWorkstation"
    />
  </el-dialog>
</template>
<script>
import { addObj, getObj, putObj } from '@/api/accounting/unitwork'
import { validateSixDecimalPositive } from '../../../util/validate'
import PartDialog from '@/views/common/part.vue'
import OperationDialog from '@/views/common/operation.vue'
import WorkstationDialog from '@/views/common/workstation.vue'

export default {
  components: {
    PartDialog,
    OperationDialog,
    WorkstationDialog
  },
  data() {
    return {
      visible: false,
      showOperate: false,
      showWorkstation: false,
      showPart: false,
      dataForm: {
        id: 0,
        partId: null,
        partNo: null,
        partName: null,
        workstationId: null,
        workstationNo: null,
        workstationName: null,
        operationId: null,
        operationNo: null,
        operationName: null,
        quota: null
      },
      dataRule: {
        partNo: [
          { required: true, message: '零件号不能为空', trigger: 'blur' }
        ],
        workstationNo: [
          { required: true, message: '机台不能为空', trigger: 'blur' }
        ],
        quota: [
          { required: true, message: '定额不能为空', trigger: 'blur' },
          { validator: validateSixDecimalPositive, trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        } else {
          this.initData()
        }
      })
    },
    initData() {
      this.dataForm.id = 0
      this.dataForm.partId = null
      this.dataForm.partNo = null
      this.dataForm.partName = null
      this.dataForm.workstationId = null
      this.dataForm.workstationNo = null
      this.dataForm.workstationName = null
      this.dataForm.operationId = null
      this.dataForm.operationNo = null
      this.dataForm.operationName = null
      this.dataForm.quota = null
    },
    openOperationDialog() {
      this.showOperate = true
    },
    selectOperation(param) {
      if (param) {
        this.dataForm.operationId = param.id
        this.dataForm.operationNo = param.operationNo
        this.dataForm.operationName = param.name
      }
    },
    openWorkstationDialog() {
      this.showWorkstation = true
    },
    selectWorkstation(param) {
      if (param) {
        this.dataForm.workstationId = param.id
        this.dataForm.workstationNo = param.workstationNo
        this.dataForm.workstationName = param.name
      }
    },
    openPartDialog() {
      this.showPart = true
    },
    selectPart(param) {
      if (param) {
        this.dataForm.partId = param.id
        this.dataForm.partNo = param.partNo
        this.dataForm.partName = param.partName
      }
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          // 去除零件编号两边的空格
          if (this.dataForm.id) {
            putObj(this.dataForm)
              .then((data) => {
                this.$message.success('修改成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch((error) => {
                this.isSubmit = false
                console.log(error)
              })
          } else {
            addObj(this.dataForm)
              .then((data) => {
                this.$message.success('添加成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch((error) => {
                this.isSubmit = false
                console.log(error)
              })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  },
  mounted() {}
}
</script>
